// Fig. 17.20: DrawPolygons.cs
// Demonstrating polygons.
using System;
using System.Collections;
using System.Drawing;
using System.Windows.Forms;

// demonstrating polygons
public partial class PolygonForm : Form
{
   // default constructor
   public PolygonForm()
   {
      InitializeComponent();
   } // end constructor

   // contains list of polygon vertices
   private ArrayList points = new ArrayList();

   // initialize default pen and brush
   Pen pen = new Pen( Color.DarkBlue );
   SolidBrush brush = new SolidBrush( Color.DarkBlue );

   // draw panel mouse down event handler
   private void drawPanel_MouseDown( object sender, MouseEventArgs e )
   {
      // add mouse position to vertex list
      points.Add( new Point( e.X, e.Y ) );
      drawPanel.Invalidate(); // refresh panel
   } // end method drawPanel_MouseDown

   // draw panel Paint event handler
   private void drawPanel_Paint( object sender, PaintEventArgs e )
   {
      // get graphics object for panel
      Graphics graphicsObject = e.Graphics;

      // if arraylist has 2 or more points, display shape
      if ( points.Count > 1 )
      {
         // get array for use in drawing functions
         Point[] pointArray = 
            ( Point[] ) points.ToArray( points[ 0 ].GetType() );

         if ( lineOption.Checked )
            graphicsObject.DrawLines( pen, pointArray );
         else if ( polygonOption.Checked )
            graphicsObject.DrawPolygon( pen, pointArray );
         else if ( filledPolygonOption.Checked )
            graphicsObject.FillPolygon( brush, pointArray );
      } // end if
   } // end method drawPanel_Paint

   // handle clearButton click event
   private void clearButton_Click( object sender, EventArgs e )
   {
      points.Clear(); // remove points
      drawPanel.Invalidate(); // refresh panel
   } // end method clearButton_Click

   // handle polygon RadioButton CheckedChanged event
   private void polygonOption_CheckedChanged(
      object sender, System.EventArgs e )
   {
      drawPanel.Invalidate(); // refresh panel
   } // end method polygonOption_CheckedChanged

   // handle line ReadioButton CheckedChanged event
   private void lineOption_CheckedChanged(
      object sender, System.EventArgs e )
   {
      drawPanel.Invalidate(); // refresh panel
   } // end method lineOption_CheckedChanged

   // handle filled polygon RadioButton CheckedChanged event
   private void filledPolygonOption_CheckedChanged(
      object sender, System.EventArgs e )
   {
      drawPanel.Invalidate(); // refresh panel
   } // end method filledPolygonOption_CheckedChanged

   // handle colorButton Click event
   private void colorButton_Click( object sender, EventArgs e )
   {
      // create new color dialog
      ColorDialog dialogColor = new ColorDialog();

      // show dialog and obtain result
      DialogResult result = dialogColor.ShowDialog();

      // return if user cancels
      if ( result == DialogResult.Cancel )
         return;

      pen.Color = dialogColor.Color; // set pen to color
      brush.Color = dialogColor.Color; // set brush
      drawPanel.Invalidate(); // refresh panel;
   } // end method colorButton_Click
} // end class PolygonForm


/**************************************************************************
 * (C) Copyright 1992-2006 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/ 