// Fig. 17.28: Agent.cs
// Microsoft Agent demonstration.
using System;
using System.Collections;
using System.Windows.Forms;
using System.IO;

public partial class Agent : Form
{
   // current agent object
   private AgentObjects.IAgentCtlCharacter speaker;

   // default constructor
   public Agent()
   {
      InitializeComponent();

      // initialize the characters
      try
      {
         // load characters into agent object
         mainAgent.Characters.Load( "Genie",
            @"C:\windows\msagent\chars\Genie.acs" );
         mainAgent.Characters.Load( "Merlin",
            @"C:\windows\msagent\chars\Merlin.acs" );
         mainAgent.Characters.Load( "Peedy",
            @"C:\windows\msagent\chars\Peedy.acs" );
         mainAgent.Characters.Load( "Robby",
            @"C:\windows\msagent\chars\Robby.acs" );

         // set current character to Genie and show him
         speaker = mainAgent.Characters[ "Genie" ];
         GetAnimationNames(); // obtain an animation name list
         speaker.Show( 0 ); // display Genie
         characterCombo.SelectedText = "Genie";
      } // end try
      catch ( FileNotFoundException )
      {
         MessageBox.Show( "Invalid character location",
            "Error", MessageBoxButtons.OK, MessageBoxIcon.Error );
      } // end catch
   } // end constructor

   // event handler for Speak Button
   private void speakButton_Click( object sender, EventArgs e )
   {
      // if textbox is empty, have the character ask
      // user to type the words into the TextBox; otherwise,
      // have the character say the words in the TextBox
      if ( speechTextBox.Text == "" )
         speaker.Speak(
            "Please, type the words you want me to speak", "" );
      else
         speaker.Speak( speechTextBox.Text, "" );
   } // end method speakButton_Click

   // event handler for Agent control's ClickEvent
   private void mainAgent_ClickEvent(
      object sender, AxAgentObjects._AgentEvents_ClickEvent e )
   {
      speaker.Play( "Confused" );
      speaker.Speak( "Why are you poking me?", "" );
      speaker.Play( "RestPose" );
   } // end method mainAgent_ClickEvent

   // ComboBox changed event, switch active agent character
   private void characterCombo_SelectedIndexChanged(
      object sender, EventArgs e )
   {
      ChangeCharacter( characterCombo.Text );
   } // end method characterCombo_SelectedIndexChanged

   // utility method to change characters
   private void ChangeCharacter( string name )
   {
      speaker.StopAll( "Play" );
      speaker.Hide( 0 );
      speaker = mainAgent.Characters[ name ];

      // regenerate animation name list
      GetAnimationNames();
      speaker.Show( 0 );
   } // end method ChangeCharacter

   // get animation names and store in ArrayList
   private void GetAnimationNames()
   {
      // ensure thread safety
      lock ( this )
      {
         // get animation names
         IEnumerator enumerator = mainAgent.Characters[ 
            speaker.Name ].AnimationNames.GetEnumerator();

         string voiceString;

         // clear actionsCombo
         actionsCombo.Items.Clear();
         speaker.Commands.RemoveAll();

         // copy enumeration to ArrayList
         while ( enumerator.MoveNext() )
         {
            // remove underscores in speech string
            voiceString = ( string ) enumerator.Current;
            voiceString = voiceString.Replace( "_", "underscore" );

            actionsCombo.Items.Add( enumerator.Current );

            // add all animations as voice enabled commands
            speaker.Commands.Add( ( string ) enumerator.Current,
               enumerator.Current, voiceString, true, false );
         } // end while

         // add custom command
         speaker.Commands.Add( "MoveToMouse", "MoveToMouse",
            "MoveToMouse", true, true );
      } // end lock
   } // end method GetAnimationNames

   // user selects new action
   private void actionsCombo_SelectedIndexChanged(
      object sender, EventArgs e )
   {
      speaker.StopAll( "Play" );
      speaker.Play( actionsCombo.Text );
      speaker.Play( "RestPose" );
   } // end method actionsCombo_SelectedIndexChanged

   // event handler for Agent commands
   private void mainAgent_Command(
      object sender, AxAgentObjects._AgentEvents_CommandEvent e )
   {
      // get UserInput object
      AgentObjects.IAgentCtlUserInput command =
         ( AgentObjects.IAgentCtlUserInput ) e.userInput;

      // change character if user speaks character name
      if ( command.Voice == "Peedy" || command.Voice == "Robby" ||
         command.Voice == "Merlin" || command.Voice == "Genie" )
      {
         ChangeCharacter( command.Voice );
         return;
      } // end if

      // send agent to mouse
      if ( command.Voice == "MoveToMouse" )
      {
         speaker.MoveTo( Convert.ToInt16( Cursor.Position.X - 60 ),
            Convert.ToInt16( Cursor.Position.Y - 60 ), 5 );
         return;
      } // end if

      // play new animation
      speaker.StopAll( "Play" );
      speaker.Play( command.Name );
   }
} // end class Agent
 
/**************************************************************************
 * (C) Copyright 1992-2006 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/